/*=================================================================*\
  Example: CLAD (Censored Least Absolute Deviation)
  First we create simulated data using a skewed error term "err".
  Variable y is censored to the left. You can see the use of the
  interface vector "dna" in the fitness function "clad".
\*=================================================================*/
clear all
set mem 10m
set more off

set obs 1000
gen double x1 = invnorm(uniform())
gen double x2 = uniform()
gen double err = exp(invnorm(uniform()))
sum err, d
replace err = err - r(p50)
gen double y = x1 + x2 + 1 + err
replace y = 0 if y < 0

cap program drop clad
program define clad
	tempvar score xb
	qui gen double `xb' = x1*dna[1,1] + x2*dna[1,2] + dna[1,3]
	qui egen double `score' = sum(abs(y - max(`xb',0)))
	qui matrix dna[1,$DNAFIT] = _N/`score'[1]
end

dna clear
dna fun clad
dna len 3
dna pop 30
dna off 60
dna rad 1 40
dna mut 1 40
dna gen 500
dna sel 1
dna sta 20
dna info
dna go
